
<?php
/*
 *  Copyright (c) 2014 The CCP project authors. All Rights Reserved.
 *
 *  Use of this source code is governed by a Beijing Speedtong Information Technology Co.,Ltd license
 *  that can be found in the LICENSE file in the root of the web site.
 *
 *   http://www.yuntongxun.com
 *
 *  An additional intellectual property rights grant can be found
 *  in the file PATENTS.  All contributing project authors may
 *  be found in the AUTHORS file in the root of the source tree.
 */


class REST {
	private $AccountSid;					//云通讯平台主帐号
	private $AccountToken;				//云通讯平台主帐号token
	private $AppId;								//云通讯平台应用id
	private $ServerIP;						//REST请求地址
	private $ServerPort;					//REST请求端口 
	private $SoftVersion;					//REST版本号
	private $Batch;  							//时间戳
	private $enabeLog = true; 		//日志开关。true为开启日志，false为关闭日志
	private $Filename="log.txt";	//日志文件名
	private $Handle; 
	function __construct($ServerIP,$ServerPort,$SoftVersion)	
	{
		$this->Batch = date("YmdHis");
		$this->ServerIP = $ServerIP;
		$this->ServerPort = $ServerPort;
		$this->SoftVersion = $SoftVersion;
        $this->Handle = fopen($this->Filename, 'a');
	}

   /**
    * 设置主帐号
    * 
    * @param AccountSid 主帐号
    * @param AccountToken 主帐号Token
    */    
    function setAccount($AccountSid,$AccountToken){
      $this->AccountSid = $AccountSid;
      $this->AccountToken = $AccountToken;   
    }
    
    
   /**
    * 设置应用ID
    * 
    * @param AppId 应用ID
    */
    function setAppId($AppId){
       $this->AppId = $AppId; 
    }
    
   /**
    * 打印日志
    * 
    * @param log 日志内容
    */
    function showlog($log){
      if($this->enabeLog){
         fwrite($this->Handle,$log."\n");  
      }
    }
    
    /**
     * 发起HTTPS请求
     */
     function curl_post($url,$data,$header,$post=1)
     {
       //初始化curl
       $ch = curl_init();
       //参数设置  
       $res= curl_setopt ($ch, CURLOPT_URL,$url);  
       curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, FALSE);
       curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
       curl_setopt ($ch, CURLOPT_HEADER, 0);
       curl_setopt($ch, CURLOPT_POST, $post);
       if($post)
          curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
       curl_setopt ($ch, CURLOPT_RETURNTRANSFER, 1);
       curl_setopt($ch,CURLOPT_HTTPHEADER,$header);
       $result = curl_exec ($ch);
       //连接失败
       if($result == FALSE){
          $result = "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"yes\"?><Response><statusCode>172001</statusCode><statusMsg>网络错误</statusMsg></Response>";   
       }

       curl_close($ch);
       return $result;
     } 

	/**
	 * 创建会议 
	 * @param action					会议创建通知的回调url地址。自定义的相对地址，默认值为空
	 * @param maxmember 			最大会议人数，不能大于300。默认值为3
	 * @param passwd 					加入会议密码。默认为空，暂时设置无法使用
	 * @param passwderrorurl	密码输入三次错误的回调url地址。自定义的相对地址，默认为空，暂时设置无法使用
	 * @param dtmfreporturl 	会议中DTMF上报通知的回调url地址。自定义的相对地址，默认值为空
	 * @param delreporturl 		会议被删除通知的回调url地址。自定义的相对地址，默认值为空
   * @param confduration 		此次会议时长单位是秒，小于等于0时则不限时，到时后会议自动结束。第一个成员加入后开始计时，默认值为0
   * @param autohangup 			会议自动结束后是否自动挂断用户电话，默认值为false 
   * @param confendprompt 	会议自动结束前的提示音，为空则不播放。默认值为空 
   * @param autorecord 			是否自动录音，true为录音，false为不录音。默认值为false 
   * @param quiturl 				退出会议通知的回调url地址。自定义的相对地址，默认值为空
   * @param mediaopturl 		会议媒体控制结果通知的回调url地址。自定义的相对地址，默认值为空 
   * @param autojoin 				是否自动加入会议。通过IVR响应命令调用时有效。默认为false 
   * @param joinurl 				加入会议通知的回调url地址。自定义的相对地址，默认值为空 
	 */
	  function CreateConf ($action,$maxmember,$passwd,$passwderrorurl,$dtmfreporturl,$delreporturl,$confduration,$autohangup,$confendprompt,$autorecord,$quiturl,$mediaopturl,$autojoin,$joinurl)
	  {
        //主帐号鉴权信息验证，对必选参数进行判空。
        $auth=$this->accAuth();
        if($auth!=""){
            return $auth;
        }
        // 拼接请求包体
        $body="<Request>
                <Appid>$this->AppId</Appid>
                <CreateConf action='$action' maxmember='$maxmember' passwd='$passwd' passwderrorurl='$passwderrorurl' dtmfreporturl='$dtmfreporturl' delreporturl='$delreporturl' confduration='$confduration' autohangup='$autohangup' confendprompt='$confendprompt' autorecord='$autorecord' quiturl='$quiturl' mediaopturl='$mediaopturl' autojoin='$autojoin' joinurl='$joinurl'/>
                </Request>";
        $this->showlog("request body = ".$body);
        // 大写的sig参数  
        $sig =  strtoupper(md5($this->AccountSid . $this->AccountToken . $this->Batch));
        // 生成请求URL
        $url="https://$this->ServerIP:$this->ServerPort/$this->SoftVersion/Accounts/$this->AccountSid/ivr/createconf?sig=$sig";
        $this->showlog("request url = ".$url);
        // 生成授权：主帐号Id + 英文冒号 + 时间戳
        $authen = base64_encode($this->AccountSid . ":" . $this->Batch);
        // 生成包头 
        $header = array("Accept:application/xml","Content-Type:application/xml;charset=utf-8","Authorization:$authen");
        // 发请求
        $result = $this->curl_post($url,$body,$header);
        $this->showlog("response body = ".$result);
		
        //$datas = simplexml_load_string(trim($result," \t\n\r"));
        return $result;
	  }
	  
	/**
	 * 邀请加入会议
	 * @param confid	会议Id，由云通讯平台产生，通过创建会议获取 
	 * @param number	被邀请者的手机号、座机号或voip帐号
	 * @param action	会议邀请结果通知的回调url地址。自定义的相对地址，默认值为空 
	 * @param role		加入会议的角色。会议中只有一个主持人，以最后一个为准。0：普通成员，1：主持人，默认值为0 
   * @param speak		是否可讲，0：不可讲，1：可讲，默认值为1 
   * @param joinurl	成功加入会议通知的回调url地址。自定义的相对地址，默认值为空
	 */
	  function InviteJoinConf($confid,$number,$action,$role,$speak,$joinurl)
	  {
        //主帐号鉴权信息验证，对必选参数进行判空。
        $auth=$this->accAuth();
        if($auth!=""){
            return $auth;
        }
        // 拼接请求包体
        $body="<Request>
                <Appid>$this->AppId</Appid>
                <InviteJoinConf confid='$confid' number='$number' action='$action' role='$role' speak='$speak' joinurl='$joinurl' />
                </Request>";
        //echo  $body;   
        $this->showlog("request body = ".$body);
        // 大写的sig参数  
        $sig =  strtoupper(md5($this->AccountSid . $this->AccountToken . $this->Batch));
        // 生成请求URL
        $url="https://$this->ServerIP:$this->ServerPort/$this->SoftVersion/Accounts/$this->AccountSid/ivr/conf?sig=$sig&confid=$confid";
        $this->showlog("request url = ".$url);
        // 生成授权：主帐号Id + 英文冒号 + 时间戳
        $authen = base64_encode($this->AccountSid . ":" . $this->Batch);
        // 生成包头 
        $header = array("Accept:application/xml","Content-Type:application/xml;charset=utf-8","Authorization:$authen");
        // 发请求
        $result = $this->curl_post($url,$body,$header);
        $this->showlog("response body = ".$result);
		
        //$datas = simplexml_load_string(trim($result," \t\n\r"));
        return $result;
	  }
      
     /**
     * 静音
     * @param callid 呼叫Id，由云通讯平台产生，是一路通话的唯一标识 
     * @param confid 会议Id，由云通讯平台产生，通过创建会议获取
     * @param action 会议媒体控制结果通知的回调url地址。自定义的相对地址，默认值为空  
     */
      function ConfMute($callid,$confid,$action)
      {
        //主帐号鉴权信息验证，对必选参数进行判空。
        $auth=$this->accAuth();
        if($auth!=""){
            return $auth;
        }
        // 拼接请求包体
        $body="<Request>
                <Appid>$this->AppId</Appid>
                <ConfMute callid='$callid' confid='$confid' action='$action' />
                </Request>";
        //echo  $body;   
        $this->showlog("request body = ".$body);
        // 大写的sig参数  
        $sig =  strtoupper(md5($this->AccountSid . $this->AccountToken . $this->Batch));
        // 生成请求URL
        $url="https://$this->ServerIP:$this->ServerPort/$this->SoftVersion/Accounts/$this->AccountSid/ivr/conf?sig=$sig&confid=$confid";
        $this->showlog("request url = ".$url);
        // 生成授权：主帐号Id + 英文冒号 + 时间戳
        $authen = base64_encode($this->AccountSid . ":" . $this->Batch);
        // 生成包头 
        $header = array("Accept:application/xml","Content-Type:application/xml;charset=utf-8","Authorization:$authen");
        // 发请求
        $result = $this->curl_post($url,$body,$header);
        $this->showlog("response body = ".$result);
        
        //$datas = simplexml_load_string(trim($result," \t\n\r"));
        return $result;
      }
      
     /**
     * 取消静音
     * @param callid 呼叫Id，由云通讯平台产生，是一路通话的唯一标识
     * @param confid 会议Id，由云通讯平台产生，通过创建会议获取 
     * @param action 会议媒体控制结果通知的回调url地址。自定义的相对地址，默认值为空 
     */
      function ConfUnMute($callid,$confid,$action)
      {
        //主帐号鉴权信息验证，对必选参数进行判空。
        $auth=$this->accAuth();
        if($auth!=""){
            return $auth;
        }
        // 拼接请求包体
        $body="<Request>
                <Appid>$this->AppId</Appid>
                <ConfUnMute callid='$callid' confid='$confid' action='$action' />
                </Request>";
        //echo  $body;   
        $this->showlog("request body = ".$body);
        // 大写的sig参数  
        $sig =  strtoupper(md5($this->AccountSid . $this->AccountToken . $this->Batch));
        // 生成请求URL
        $url="https://$this->ServerIP:$this->ServerPort/$this->SoftVersion/Accounts/$this->AccountSid/ivr/conf?sig=$sig&confid=$confid";
        $this->showlog("request url = ".$url);
        // 生成授权：主帐号Id + 英文冒号 + 时间戳
        $authen = base64_encode($this->AccountSid . ":" . $this->Batch);
        // 生成包头 
        $header = array("Accept:application/xml","Content-Type:application/xml;charset=utf-8","Authorization:$authen");
        // 发请求
        $result = $this->curl_post($url,$body,$header);
        $this->showlog("response body = ".$result);
        
        //$datas = simplexml_load_string(trim($result," \t\n\r"));
        return $result;
      }
	  
	     /**
    * IVR外呼
    * @param number   待呼叫号码，为Dial节点的属性
    * @param userdata 用户数据，在<startservice>通知中返回，只允许填写数字字符，为Dial节点的属性
    * @param record   是否录音，可填项为true和false，默认值为false不录音，为Dial节点的属性
    */
    function ivrDial($number,$userdata,$record)
    {                                                                              
        $Batch = date("YmdHis");
       // 拼接请求包体
        $body=" <Request>
                  <Appid>$this->AppId</Appid>
                  <Dial number='$number'  userdata='$userdata' record='$record'></Dial>
                </Request>";
        // 大写的sig参数
        $sig =  strtoupper(md5($this->AccountSid . $this->AccountToken . $this->Batch));
        // 生成请求URL  
        $url="https://$this->ServerIP:$this->ServerPort/$this->SoftVersion/Accounts/$this->AccountSid/ivr/dial?sig=$sig";

        // 生成授权：主帐户Id + 英文冒号 + 时间戳。
        $authen = base64_encode($this->AccountSid . ":" . $this->Batch);
        // 生成包头 
        $header = array("Accept:application/xml","Content-Type:application/xml;charset=utf-8","Authorization:$authen");
        // 发请求
        $result = $this->curl_post($url,$body,$header);
        $this->showlog("response body = ".$result);
        
        $datas = simplexml_load_string(trim($result," \t\n\r"));
        return $datas;
    }
	
	 /**
     * 解散会议 
     * @param action			解散会议操作结果通知回调url。自定义的相对地址，默认值为空
     * @param confid			会议Id，由云通讯平台产生，通过创建会议获取 
     * @param delurl			会议被删除通知的相对url地址。自定义的相对地址，默认值为空
		 * @param autohangup	会议自动解散后是否自动挂断用户，true表示挂断，false不挂断。默认值为false 
		 * @param quiturl			解散时参会者退出会议通知的回调url地址。若自动挂断则不发送。默认值为空 
		 * @param recordurl		录音控制结果通知的回调url地址。自定义的相对地址，默认值为空
     */
      function DismissConf($action,$confid,$delurl,$autohangup,$quiturl,$recordurl)
      {
        //主帐号鉴权信息验证，对必选参数进行判空。
        $auth=$this->accAuth();
        if($auth!=""){
            return $auth;
        }
        // 拼接请求包体
        $body="<Request>
                <Appid>$this->AppId</Appid>
                <DismissConf action='$action' confid='$confid' delurl='$delurl' autohangup='$autohangup' quiturl='quiturl' recordurl='$recordurl' />
                </Request>";
        //echo  $body;   
        $this->showlog("request body = ".$body);
        // 大写的sig参数  
        $sig =  strtoupper(md5($this->AccountSid . $this->AccountToken . $this->Batch));
        // 生成请求URL
        $url="https://$this->ServerIP:$this->ServerPort/$this->SoftVersion/Accounts/$this->AccountSid/ivr/conf?sig=$sig&confid=$confid";
        $this->showlog("request url = ".$url);
        // 生成授权：主帐号Id + 英文冒号 + 时间戳
        $authen = base64_encode($this->AccountSid . ":" . $this->Batch);
        // 生成包头 
        $header = array("Accept:application/xml","Content-Type:application/xml;charset=utf-8","Authorization:$authen");
        // 发请求
        $result = $this->curl_post($url,$body,$header);
        $this->showlog("response body = ".$result);
        
        //$datas = simplexml_load_string(trim($result," \t\n\r"));
        return $result;
      }
	  
	 /**
     * 退出会议
     * @param callid 呼叫Id，由云通讯平台产生，是一路通话的唯一标识 
     * @param confid 会议Id，由云通讯平台产生，通过创建会议获取 
     * @param action 退出会议通知的回调url地址。自定义的相对地址，默认值为空
     */
      function QuitConf($callid,$confid,$action)
      {
        //主帐号鉴权信息验证，对必选参数进行判空。
        $auth=$this->accAuth();
        if($auth!=""){
            return $auth;
        }
        // 拼接请求包体
        $body="<Request>
                <Appid>$this->AppId</Appid>
                <QuitConf callid='$callid' confid='$confid' action='$action' />
                </Request>";
        //echo  $body;   
        $this->showlog("request body = ".$body);
        // 大写的sig参数  
        $sig =  strtoupper(md5($this->AccountSid . $this->AccountToken . $this->Batch));
        // 生成请求URL
        $url="https://$this->ServerIP:$this->ServerPort/$this->SoftVersion/Accounts/$this->AccountSid/ivr/conf?sig=$sig&confid=$confid";
        $this->showlog("request url = ".$url);
        // 生成授权：主帐号Id + 英文冒号 + 时间戳
        $authen = base64_encode($this->AccountSid . ":" . $this->Batch);
        // 生成包头 
        $header = array("Accept:application/xml","Content-Type:application/xml;charset=utf-8","Authorization:$authen");
        // 发请求
        $result = $this->curl_post($url,$body,$header);
        $this->showlog("response body = ".$result);
        
        //$datas = simplexml_load_string(trim($result," \t\n\r"));
        return $result;
      }
	  
	/**
     * 会议放音
     * @param confid					会议Id，由云通讯平台产生，是一路通话的唯一标识
     * @param filename				会议放音文件名，wav格式
     * @param loop						循环次数，正整数值，0不播放　-1无限循环，默认值为1 
     * @param action					会议媒体控制结果通知的回调url地址，不论成功与失败只要不为空则发送请求。自定义的相对地址，默认值为空
     * @param playcompleteurl	放音完成通知的回调url地址。自定义的相对地址，默认值为空 
     */
      function ConfPlay($confid,$filename,$loop,$action,$playcompleteurl)
      {
        //主帐号鉴权信息验证，对必选参数进行判空。
        $auth=$this->accAuth();
        if($auth!=""){
            return $auth;
        }
        // 拼接请求包体
        $body="<Request>
                <Appid>$this->AppId</Appid>
                <ConfPlay confid='$confid' filename='$filename' loop='$loop' action='$action' playcompleteurl='$playcompleteurl' />
                </Request>";
        //echo  $body;   
        $this->showlog("request body = ".$body);
        // 大写的sig参数  
        $sig =  strtoupper(md5($this->AccountSid . $this->AccountToken . $this->Batch));
        // 生成请求URL
        $url="https://$this->ServerIP:$this->ServerPort/$this->SoftVersion/Accounts/$this->AccountSid/ivr/conf?sig=$sig&confid=$confid";
        $this->showlog("request url = ".$url);
        // 生成授权：主帐号Id + 英文冒号 + 时间戳
        $authen = base64_encode($this->AccountSid . ":" . $this->Batch);
        // 生成包头 
        $header = array("Accept:application/xml","Content-Type:application/xml;charset=utf-8","Authorization:$authen");
        // 发请求
        $result = $this->curl_post($url,$body,$header);
        $this->showlog("response body = ".$result);
        
        //$datas = simplexml_load_string(trim($result," \t\n\r"));
        return $result;
      }
	  
	 /**
     * 停止会议放音
     * @param confid 会议Id，由云通讯平台产生，是一路通话的唯一标识
     * @param action 会议媒体控制结果通知的回调url地址，不论成功与失败只要不为空则发送请求。自定义的相对地址，默认值为空
     */
      function ConfStopPlay($confid,$action)
      {
        //主帐号鉴权信息验证，对必选参数进行判空。
        $auth=$this->accAuth();
        if($auth!=""){
            return $auth;
        }
        // 拼接请求包体
        $body="<Request>
                <Appid>$this->AppId</Appid>
                <ConfStopPlay confid='$confid' action='$action' />
                </Request>";
        //echo  $body;   
        $this->showlog("request body = ".$body);
        // 大写的sig参数  
        $sig =  strtoupper(md5($this->AccountSid . $this->AccountToken . $this->Batch));
        // 生成请求URL
        $url="https://$this->ServerIP:$this->ServerPort/$this->SoftVersion/Accounts/$this->AccountSid/ivr/conf?sig=$sig&confid=$confid";
        $this->showlog("request url = ".$url);
        // 生成授权：主帐号Id + 英文冒号 + 时间戳
        $authen = base64_encode($this->AccountSid . ":" . $this->Batch);
        // 生成包头 
        $header = array("Accept:application/xml","Content-Type:application/xml;charset=utf-8","Authorization:$authen");
        // 发请求
        $result = $this->curl_post($url,$body,$header);
        $this->showlog("response body = ".$result);
        
        //$datas = simplexml_load_string(trim($result," \t\n\r"));
        return $result;
      }
	  
	 /**
     * 会议录音
     * @param confid						会议Id，由云通讯平台产生，是一路通话的唯一标识
     * @param action						会议媒体控制结果通知的回调url地址，不论成功与失败只要不为空则发送请求。自定义的相对地址，默认值为空
     * @param time							录音时长，单位为秒。默认值为0，不限时。 
     * @param timeoutrecordurl	录音时长到时的录音结果通知的回调url地址。自定义的相对地址，默认值为空 
     */
      function ConfRecord($confid,$action,$time,$timeoutrecordurl)
      {
        //主帐号鉴权信息验证，对必选参数进行判空。
        $auth=$this->accAuth();
        if($auth!=""){
            return $auth;
        }
        // 拼接请求包体
        $body="<Request>
                <Appid>$this->AppId</Appid>
                <ConfRecord confid='$confid' action='$action' time='$time' timeoutrecordurl='$timeoutrecordurl' />
                </Request>";
        //echo  $body;   
        $this->showlog("request body = ".$body);
        // 大写的sig参数  
        $sig =  strtoupper(md5($this->AccountSid . $this->AccountToken . $this->Batch));
        // 生成请求URL
        $url="https://$this->ServerIP:$this->ServerPort/$this->SoftVersion/Accounts/$this->AccountSid/ivr/conf?sig=$sig&confid=$confid";
        $this->showlog("request url = ".$url);
        // 生成授权：主帐号Id + 英文冒号 + 时间戳
        $authen = base64_encode($this->AccountSid . ":" . $this->Batch);
        // 生成包头 
        $header = array("Accept:application/xml","Content-Type:application/xml;charset=utf-8","Authorization:$authen");
        // 发请求
        $result = $this->curl_post($url,$body,$header);
        $this->showlog("response body = ".$result);
        
        //$datas = simplexml_load_string(trim($result," \t\n\r"));
        return $result;
      }
	  
	 /**
     * 停止会议录音
     * @param confid 会议Id，由云通讯平台产生，是一路通话的唯一标识
     * @param action 会议媒体控制结果通知的回调url地址。不论成功与失败只要不为空则发送请求。自定义的相对地址，默认值为空 
     */
      function ConfStopRecord ($confid,$action)
      {
        //主帐号鉴权信息验证，对必选参数进行判空。
        $auth=$this->accAuth();
        if($auth!=""){
            return $auth;
        }
        // 拼接请求包体
        $body="<Request>
                <Appid>$this->AppId</Appid>
                <ConfStopRecord confid='$confid' action='$action' />
                </Request>";
        //echo  $body;   
        $this->showlog("request body = ".$body);
        // 大写的sig参数  
        $sig =  strtoupper(md5($this->AccountSid . $this->AccountToken . $this->Batch));
        // 生成请求URL
        $url="https://$this->ServerIP:$this->ServerPort/$this->SoftVersion/Accounts/$this->AccountSid/ivr/conf?sig=$sig&confid=$confid";
        $this->showlog("request url = ".$url);
        // 生成授权：主帐号Id + 英文冒号 + 时间戳
        $authen = base64_encode($this->AccountSid . ":" . $this->Batch);
        // 生成包头 
        $header = array("Accept:application/xml","Content-Type:application/xml;charset=utf-8","Authorization:$authen");
        // 发请求
        $result = $this->curl_post($url,$body,$header);
        $this->showlog("response body = ".$result);
        
        //$datas = simplexml_load_string(trim($result," \t\n\r"));
        return $result;
      }
	  
	 /**
     * 调节会议音量
     * @param confid			会议Id，由云通讯平台产生，是一路通话的唯一标识
     * @param adjusttype	增加或减小会议音量。True增加音量　false减小音量 
     * @param action			会议媒体控制结果通知的回调url地址，不论成功与失败只要不为空则发送请求。自定义的相对地址，默认值为空   
     */
      function ConfVolumeAdjust($confid,$adjusttype,$action)
      {
        //主帐号鉴权信息验证，对必选参数进行判空。
        $auth=$this->accAuth();
        if($auth!=""){
            return $auth;
        }
        // 拼接请求包体
        $body="<Request>
                <Appid>$this->AppId</Appid>
                <ConfVolumeAdjust confid='$confid' adjusttype='$adjusttype' action='$action' />
                </Request>";
        //echo  $body;   
        $this->showlog("request body = ".$body);
        // 大写的sig参数  
        $sig =  strtoupper(md5($this->AccountSid . $this->AccountToken . $this->Batch));
        // 生成请求URL
        $url="https://$this->ServerIP:$this->ServerPort/$this->SoftVersion/Accounts/$this->AccountSid/ivr/conf?sig=$sig&confid=$confid";
        $this->showlog("request url = ".$url);
        // 生成授权：主帐号Id + 英文冒号 + 时间戳
        $authen = base64_encode($this->AccountSid . ":" . $this->Batch);
        // 生成包头 
        $header = array("Accept:application/xml","Content-Type:application/xml;charset=utf-8","Authorization:$authen");
        // 发请求
        $result = $this->curl_post($url,$body,$header);
        $this->showlog("response body = ".$result);
        
        //$datas = simplexml_load_string(trim($result," \t\n\r"));
        return $result;
      }
	  
	 /**
     * 会议成员禁听
     * @param confid	会议Id，由云通讯平台产生，是一路通话的唯一标识
     * @param callid	呼叫Id，由云通讯平台产生，是一路通话的唯一标识 
     * @param action	会议媒体控制结果通知的回调url地址。自定义的相对地址，默认值为空 
     */
      function ConfMemberPause ($confid,$callid,$action)
      {
        //主帐号鉴权信息验证，对必选参数进行判空。
        $auth=$this->accAuth();
        if($auth!=""){
            return $auth;
        }
        // 拼接请求包体
        $body="<Request>
                <Appid>$this->AppId</Appid>
                <ConfMemberPause  confid='$confid' callid='$callid' action='$action' />
                </Request>";
        //echo  $body;   
        $this->showlog("request body = ".$body);
        // 大写的sig参数  
        $sig =  strtoupper(md5($this->AccountSid . $this->AccountToken . $this->Batch));
        // 生成请求URL
        $url="https://$this->ServerIP:$this->ServerPort/$this->SoftVersion/Accounts/$this->AccountSid/ivr/conf?sig=$sig&confid=$confid";
        $this->showlog("request url = ".$url);
        // 生成授权：主帐号Id + 英文冒号 + 时间戳
        $authen = base64_encode($this->AccountSid . ":" . $this->Batch);
        // 生成包头 
        $header = array("Accept:application/xml","Content-Type:application/xml;charset=utf-8","Authorization:$authen");
        // 发请求
        $result = $this->curl_post($url,$body,$header);
        $this->showlog("response body = ".$result);
        
        //$datas = simplexml_load_string(trim($result," \t\n\r"));
        return $result;
      }
	  
	 /**
     * 取消会议成员禁听
     * @param confid	会议Id，由云通讯平台产生，是一路通话的唯一标识
     * @param callid	呼叫Id，由云通讯平台产生，是一路通话的唯一标识 
     * @param action	会议媒体控制结果通知的回调url地址。自定义的相对地址，默认值为空 
     * @param speak		是否可讲：0 不可讲；1 可讲。默认为0 
     */
      function ConfMemberResume($confid,$callid,$action,$speak)
      {
        //主帐号鉴权信息验证，对必选参数进行判空。
        $auth=$this->accAuth();
        if($auth!=""){
            return $auth;
        }
        // 拼接请求包体
        $body="<Request>
                <Appid>$this->AppId</Appid>
                <ConfMemberResume confid='$confid' callid='$callid' action='$action' speak='$speak' />
                </Request>";
        //echo  $body;   
        $this->showlog("request body = ".$body);
        // 大写的sig参数  
        $sig =  strtoupper(md5($this->AccountSid . $this->AccountToken . $this->Batch));
        // 生成请求URL
        $url="https://$this->ServerIP:$this->ServerPort/$this->SoftVersion/Accounts/$this->AccountSid/ivr/conf?sig=$sig&confid=$confid";
        $this->showlog("request url = ".$url);
        // 生成授权：主帐号Id + 英文冒号 + 时间戳
        $authen = base64_encode($this->AccountSid . ":" . $this->Batch);
        // 生成包头 
        $header = array("Accept:application/xml","Content-Type:application/xml;charset=utf-8","Authorization:$authen");
        // 发请求
        $result = $this->curl_post($url,$body,$header);
        $this->showlog("response body = ".$result);
        
        //$datas = simplexml_load_string(trim($result," \t\n\r"));
        return $result;
      }  
	  
	 /**
	 * 会议计时闹钟
	 * @param confid			会议Id，由云通讯平台产生，是一路通话的唯一标识
	 * @param time				闹钟计时时长，正整数，单位为秒。 
	 * @param action			设置会议计时闹钟结果通知的的回调url。自定义的相对地址，默认值为空
	 * @param timeraction 闹钟到时后的动作类型：0发送通知请求；1播放提示音；2解散会议。默认值为0 
	 * @param clockurl		会议闹钟到时后通知的请求url地址。自定义的相对地址，无自定义则为默认值alarmclock。
	 * @param promptfile	提示音文件名，wav格式
   * @param autohangup	会议自动解散后是否自动挂断用户。true表示挂断，false不挂断，默认false。 
   * @param quiturl			会议自动解散但不挂断用户时退出会议通知的回调url。若自动挂断则不发送。自定义的相对地址，默认值为空  
   * @param recordurl		录音媒体控制结果通知的回调url，有录音才会回调。自定义的相对地址，默认值为空
   * @param delurl			会议被删除通知的回调url。自定义的相对地址，默认值为空
	 */
	  function ConfAlarmClock($confid,$time,$action,$timeraction,$clockurl,$promptfile,$autohangup,$quiturl,$recordurl,$delurl)
	  {
        //主帐号鉴权信息验证，对必选参数进行判空。
        $auth=$this->accAuth();
        if($auth!=""){
            return $auth;
        }
        // 拼接请求包体
        $body="<Request>
                <Appid>$this->AppId</Appid>
                <ConfAlarmClock  confid='$confid' time='$time' action='$action' timeraction='$timeraction' clockurl='$clockurl' promptfile='$promptfile' autohangup='$autohangup' quiturl='$quiturl' recordurl='$recordurl' delurl='$delurl'/>
                </Request>";
        $this->showlog("request body = ".$body);
        // 大写的sig参数  
        $sig =  strtoupper(md5($this->AccountSid . $this->AccountToken . $this->Batch));
        // 生成请求URL
        $url="https://$this->ServerIP:$this->ServerPort/$this->SoftVersion/Accounts/$this->AccountSid/ivr/conf?sig=$sig&confid=$confid";
        $this->showlog("request url = ".$url);
        // 生成授权：主帐号Id + 英文冒号 + 时间戳
        $authen = base64_encode($this->AccountSid . ":" . $this->Batch);
        // 生成包头 
        $header = array("Accept:application/xml","Content-Type:application/xml;charset=utf-8","Authorization:$authen");
        // 发请求
        $result = $this->curl_post($url,$body,$header);
        $this->showlog("response body = ".$result);
		
        //$datas = simplexml_load_string(trim($result," \t\n\r"));
        return $result;
	  }
	  
	 /**
     * 会议状态查询
     * @param confid	会议Id，由云通讯平台产生，是一路通话的唯一标识
     * @param action	会议媒体控制结果通知的回调url地址。自定义的相对地址，默认值为空   
     */
      function QueryConfState($confid,$action)
      {
        //主帐号鉴权信息验证，对必选参数进行判空。
        $auth=$this->accAuth();
        if($auth!=""){
            return $auth;
        }
        // 拼接请求包体
        $body="<Request>
                <Appid>$this->AppId</Appid>
                <QueryConfState confid='$confid' action='$action' />
                </Request>";
        //echo  $body;   
        $this->showlog("request body = ".$body);
        // 大写的sig参数  
        $sig =  strtoupper(md5($this->AccountSid . $this->AccountToken . $this->Batch));
        // 生成请求URL
        $url="https://$this->ServerIP:$this->ServerPort/$this->SoftVersion/Accounts/$this->AccountSid/ivr/conf?sig=$sig&confid=$confid";
        $this->showlog("request url = ".$url);
        // 生成授权：主帐号Id + 英文冒号 + 时间戳
        $authen = base64_encode($this->AccountSid . ":" . $this->Batch);
        // 生成包头 
        $header = array("Accept:application/xml","Content-Type:application/xml;charset=utf-8","Authorization:$authen");
        // 发请求
        $result = $this->curl_post($url,$body,$header);
        $this->showlog("response body = ".$result);
        
        //$datas = simplexml_load_string(trim($result," \t\n\r"));
        return $result;
      }
        
  /**
    * 主帐号鉴权
    */   
   function accAuth()
   {
       if($this->ServerIP==""){
            $data = new stdClass();
            $data->statusCode = '172004';
            $data->statusMsg = 'IP为空';
          return $data;
        }
        if($this->ServerPort<=0){
            $data = new stdClass();
            $data->statusCode = '172005';
            $data->statusMsg = '端口错误（小于等于0）';
          return $data;
        }
        if($this->SoftVersion==""){
            $data = new stdClass();
            $data->statusCode = '172013';
            $data->statusMsg = '版本号为空';
          return $data;
        } 
        if($this->AccountSid==""){
            $data = new stdClass();
            $data->statusCode = '172006';
            $data->statusMsg = '主帐号为空';
          return $data;
        }
        if($this->AccountToken==""){
            $data = new stdClass();
            $data->statusCode = '172007';
            $data->statusMsg = '主帐号令牌为空';
          return $data;
        }
        if($this->AppId==""){
            $data = new stdClass();
            $data->statusCode = '172012';
            $data->statusMsg = '应用ID为空';
          return $data;
        }   
   }
}
?>
